import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import ros_cdk_assembly_schema._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@alicloud/ros-cdk-cxapi", "1.9.0", __name__[0:-6], "ros-cdk-cxapi@1.9.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
